@@ -41,7 +41,6 @@ import platform
 import re
 import glob
 
-
 __driver_index = 'https://chromedriver.chromium.org/downloads'
 __filepath = Path(__file__).resolve().parent
 __fspath = os.fspath(__filepath) + '/'
@@ -50,6 +49,7 @@ __fspath = os.fspath(__filepath) + '/'
 class __Option(Options):
     os_ = ''
     pypath = ''
+    chromedriver_path = ''
 
 option = __Option()
 
@@ -107,6 +107,7 @@ def __updata_driver(my_version, use_os):
             my_os = 'chromedriver_linux64.zip'
         elif use_os == 'win':
             my_os = 'chromedriver_win32.zip'
+            os.system("")
         elif use_os == 'mac':
             my_os = 'chromedriver_mac64.zip'
         elif use_os == 'mac_m1':
@@ -178,6 +179,8 @@ def __move_file(target_path):
     :param target_path:
     :return:
     """
+    if option.chromedriver_path != '':
+        target_path = option.chromedriver_path
     try:
         file_path = Path(__fspath + 'chromedriver.exe')
         # print(file_path)
@@ -220,20 +223,32 @@ def __deleta_files():
         Path(exe).unlink(missing_ok=True)
 
 # 修改drvier为自行传入的方式
-def driver(*args, **kwargs):
+def chrome_driver(*args, **kwargs):
+    change_mode = False
+    selenium_version = list(os.popen('pip show selenium'))[1]
+    if 'Version: 4' in selenium_version:
+        change_mode = True
     try:
         # 如果能直接获取到drvier则直接进行返回
         # 添加option配置，使其不会因函数运行结束而结束driver程序
         # 阻止关闭会出现日志报错行为，使用selenium的option选项剔除
         option.add_experimental_option("detach", True)
         option.add_experimental_option("excludeSwitches", ['enable-automation', 'enable-logging'])
-        dr = webdriver.Chrome(*args, **kwargs, options=option)
+        if option.chromedriver_path != '':
+            if change_mode is True:
+                from selenium.webdriver.chrome.service import Service
+                service = Service(executable_path=option.chromedriver_path)
+                dr = webdriver.Chrome(*args, **kwargs, service=service, options=option)
+            else:
+                dr = webdriver.Chrome(*args, **kwargs, executable_path=option.chromedriver_path , options=option)
+        else:
+            dr = webdriver.Chrome(*args, **kwargs, options=option)
         print('='*36)
         print(f'\033[1;50;32m{"*"*10} driver已正常启动 {"*"*10}\033[0m')
         print('='*36)
         return dr
     except Exception as e:
-        if str(e).find('ChromeDriver only supports') >= 1:
+        if str(e).find('ChromeDriver only supports') != -1:
             try:
                 print('=' * 97)
                 print(f'\033[1;50;31m{"*-"*10} 浏览器chromedriver文件运行异常，尝试获取并更新chromedriver文件 {"-*"*10}\033[0m')
@@ -266,7 +281,18 @@ def driver(*args, **kwargs):
                         raise Exception("未获取到driver版本名称")
                 else:
                     raise Exception('获取chrome版本失败，代码停止运行')
-                return webdriver.Chrome(*args, **kwargs, options=option)
+                option.add_experimental_option("detach", True)
+                option.add_experimental_option("excludeSwitches", ['enable-automation', 'enable-logging'])
+                if option.chromedriver_path != '':
+                    if change_mode is True:
+                        from selenium.webdriver.chrome.service import Service
+                        service = Service(executable_path=option.chromedriver_path)
+                        dr = webdriver.Chrome(*args, **kwargs, service=service, options=option)
+                    else:
+                        dr = webdriver.Chrome(*args, **kwargs, executable_path=option.chromedriver_path, options=option)
+                else:
+                    dr = webdriver.Chrome(*args, **kwargs, options=option)
+                return dr
             except Exception as e:
                 print('\033[1;50;31m更新chromedriver出错~\033[0m')
                 print(f'\033[1;50;31m{e}\033[0m')
